from django.conf import settings
from django.http import HttpResponse
from django.utils.datastructures import MultiValueDictKeyError
from tagging.models import Tag
from django.http import Http404
try:
    import json
except ImportError:
    from django.utils import simplejson as json


def list_tags(request):
    # Note that ``MAX_NUMBER_OF_RESULTS`` is deprecated.
    # Consider using ``TAGGING_AUTOCOMPLETE_MAX_RESULTS`` instead.
    max_results = getattr(
        settings, 'TAGGING_AUTOCOMPLETE_MAX_RESULTS',
        getattr(settings, 'MAX_NUMBER_OF_RESULTS', 100))
    search_contains = getattr(settings, 'TAGGING_AUTOCOMPLETE_SEARCH_CONTAINS', False)
    try:
        term = request.GET['term']
    except MultiValueDictKeyError:
        raise Http404
    if search_contains:
        objects = Tag.objects.filter(name__icontains=term)
    else:
        objects = Tag.objects.filter(name__istartswith=term)
    tags = [{'id': tag.id, 'label': tag.name, 'value': tag.name} for tag in objects[:max_results]]
    return HttpResponse(json.dumps(tags), content_type='text/json')



from django.db import models
from tagging.fields import TagField
from tagging_autocomplete.widgets import TagAutocomplete
from django.contrib.admin.widgets import AdminTextInputWidget

# The following code is based on models.py file from django-tinymce by Joost Cassee

class TagAutocompleteField(TagField):
    """
    TagField with autocomplete widget
    """
    def formfield(self, **kwargs):
        defaults = {'widget': TagAutocomplete}
        defaults.update(kwargs)

        # As an ugly hack, we override the admin widget
        if defaults['widget'] == AdminTextInputWidget:
            defaults['widget'] = TagAutocomplete(attrs={'class': 'vTextField'})

        return super(TagAutocompleteField, self).formfield(**defaults)



from django.forms.widgets import Input
from django.core.urlresolvers import reverse
from django.conf import settings
from django.utils.safestring import mark_safe

class TagAutocomplete(Input):
    input_type = 'text'
	
    def render(self, name, value, attrs=None):
        json_view = reverse('tagging_autocomplete-list')
        html = super(TagAutocomplete, self).render(name, value, attrs)
        js = u'''<script type="text/javascript">
        function split( val ) {
        return val.split( /,\s*/ );
        }
        function extractLast( term ) {
        return split( term ).pop();
        }
        jQuery(function() {

        jQuery("#%s").bind( "keydown", function( event ) {
        if ( event.keyCode === $.ui.keyCode.TAB &&
        $( this ).data( "autocomplete" ).menu.active ) {
        event.preventDefault();
        }
        }).autocomplete({
        source: function( request, response ) {
        $.getJSON( "%s", {
        term: extractLast( request.term )
        }, response );
        },
        focus: function() {
        // prevent value inserted on focus
        return false;
        },
        select: function( event, ui ) {
        var terms = split( this.value );
        // remove the current input
        terms.pop();
        // add the selected item
        terms.push( ui.item.value );
        // add placeholder to get the comma-and-space at the end
        terms.push( "" );
        this.value = terms.join( ", " );
        return false;
        }
        });
        });
        </script>''' % (attrs['id'], json_view)
        return mark_safe("\n".join([html, js]))

    class Media:
        css = {
            'all': (
                'tagging_autocomplete/css/base/jquery.ui.all.css',
                'tagging_autocomplete/css/tagging_autocomplete.css',
                )
        }

        js = (
            getattr(settings,'JQUERY_URL','tagging_autocomplete/js/jquery-1.6.2.min.js'),
            'tagging_autocomplete/js/jquery.ui.core.min.js',
            'tagging_autocomplete/js/jquery.ui.position.min.js',
            'tagging_autocomplete/js/jquery.ui.widget.min.js',
            'tagging_autocomplete/js/jquery.ui.autocomplete.min.js',
)



# -*- coding: utf-8 -*-
import os
from distutils.core import setup
from distutils.command.install import INSTALL_SCHEMES

long_description = open('README.rst').read()

# install data files where source files are installed
for scheme in INSTALL_SCHEMES.values():
    scheme['data'] = scheme['purelib']

def find_data_files(filepath):
    return sum([
        [(path, [os.path.join(path, name)]) for name in names]
            for path, _, names in os.walk(filepath)], [])

setup(
    name='django-tagging-autocomplete',
    version='0.5.0',
    description='Autocompletion for django-tagging',
    long_description=long_description,
    author='Ludwik Trammer',
    author_email='ludwik@gmail.com',
    url='https://github.com/ludwiktrammer/django-tagging-autocomplete/',
    packages=['tagging_autocomplete'],
    data_files=find_data_files('tagging_autocomplete/static'),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ]
)
